@@ -9,7 +9,7 @@ from apppath import AppPath
 
 __project__ = "Warg"
 __author__ = "Christian Heider Nielsen"
-__version__ = "1.0.0"
+__version__ = "1.0.1"
 __doc__ = r"""
 Created on 27/04/2019
 
@@ -20,6 +20,7 @@ from pathlib import Path
 
 with open(Path(__file__).parent / "README.md", "r") as this_init_file:
     __doc__ += this_init_file.read()
+# del Path
 
 # with open(Path(__file__).parent.parent / "README.md", "r") as this_init_file:
 #    __doc__ += this_init_file.read()
@@ -92,7 +93,7 @@ else:
 
 
 def get_version(append_time: Any = DEVELOP) -> str:
-    """ """
+    """description"""
     import datetime
     import os
 
