@@ -14,6 +14,13 @@ from typing import Optional, Any
 
 
 def recurse_first_args(args):
+    """
+
+    :param args:
+    :type args:
+    :return:
+    :rtype:
+    """
     for a in args:
         if isinstance(a, ast.Call):
             if isinstance(a.func, ast.Attribute):
@@ -27,7 +34,7 @@ def recurse_first_args(args):
 
 
 class FirstArgIdentifier(ast.NodeVisitor):
-    """ """
+    """description"""
 
     def __init__(
         self,
@@ -106,33 +113,36 @@ class FirstArgIdentifier(ast.NodeVisitor):
 def get_first_arg_name(
     func_name: str, *, verbose=False, max_num_intermediate_unnamed_elements=-1  # recurse = -1
 ) -> Optional[str]:
-    """ """
+    """description"""
     import inspect
     import textwrap
     import ast
 
     caller_frame = inspect.currentframe().f_back.f_back
-    caller_src_code_lines = inspect.getsourcelines(caller_frame)
-    fai = FirstArgIdentifier(
-        func_name,
-        verbose=verbose,
-        max_num_intermediate_unnamed_elements=max_num_intermediate_unnamed_elements,
-    )
-    fai.visit(ast.parse(textwrap.dedent("".join(caller_src_code_lines[0]))))
-    if func_name in fai.result:
-        offset = 0
-        if caller_src_code_lines[1]:
-            offset = caller_src_code_lines[1] - 1
-        idx = caller_frame.f_lineno - offset
-        if idx in fai.result[func_name]:
-            return fai.result[func_name][idx]
+    try:
+        caller_src_code_lines = inspect.getsourcelines(caller_frame)
+        fai = FirstArgIdentifier(
+            func_name,
+            verbose=verbose,
+            max_num_intermediate_unnamed_elements=max_num_intermediate_unnamed_elements,
+        )
+        fai.visit(ast.parse(textwrap.dedent("".join(caller_src_code_lines[0]))))
+        if func_name in fai.result:
+            offset = 0
+            if caller_src_code_lines[1]:
+                offset = caller_src_code_lines[1] - 1
+            idx = caller_frame.f_lineno - offset
+            if idx in fai.result[func_name]:
+                return fai.result[func_name][idx]
+            elif verbose:
+                print(
+                    f'Unexpected line number: {idx}, probably a wrong alias "{func_name}" was supplied, found {fai.result[func_name]}, in {inspect.getsourcefile(caller_frame)}'
+                )
         elif verbose:
-            print(
-                f'Unexpected line number: {idx}, probably a wrong alias "{func_name}" was supplied, found {fai.result[func_name]}, in {inspect.getsourcefile(caller_frame)}'
-            )
-    elif verbose:
-        print(f"{func_name} was not found in {fai.result}")
-    return None
+            print(f"{func_name} was not found in {fai.result}")
+    except Exception as e:
+        print(e)
+    return
 
 
 def get_first_arg_name_recurse() -> Optional[str]:
@@ -147,6 +157,15 @@ def get_first_arg_name_recurse() -> Optional[str]:
 
 
 def cprint(v: Any, writer: callable = print, deliminator: str = ":") -> None:
+    """
+
+    :param v:
+    :type v:
+    :param writer:
+    :type writer:
+    :param deliminator:
+    :type deliminator:
+    """
     if isinstance(v, str) and v.strip() == "":
         v = '""'
     writer(f"{get_first_arg_name('cprint')}{deliminator}", v)
@@ -155,6 +174,7 @@ def cprint(v: Any, writer: callable = print, deliminator: str = ":") -> None:
 if __name__ == "__main__":
 
     def siajd():
+        """description"""
         s = ""
         cprint(s)
         cprint("")
@@ -172,7 +192,7 @@ if __name__ == "__main__":
         from warg import FirstArgIdentifier
 
         def some_func(a):
-            """ """
+            """description"""
             caller_frame = inspect.currentframe().f_back
             # caller_src_code_snippet = inspect.getsource(caller_frame) # Only gets scope
             caller_src_code_lines = inspect.getsourcelines(caller_frame)
@@ -211,7 +231,7 @@ if __name__ == "__main__":
         from warg import FirstArgIdentifier
 
         def some_func(a):
-            """ """
+            """description"""
             caller_frame = inspect.currentframe().f_back
             # caller_src_code_snippet = inspect.getsource(caller_frame) # Only gets scope
             caller_src_code_lines = inspect.getsourcelines(caller_frame)
@@ -236,7 +256,7 @@ if __name__ == "__main__":
         from typing import Any
 
         def some_func(a: Any) -> None:
-            """ """
+            """description"""
             print(get_first_arg_name("some_func", verbose=True))
 
         some_func(print(2, sep="-"))
@@ -249,7 +269,7 @@ if __name__ == "__main__":
         import warg
 
         def some_func(a: Any) -> None:
-            """ """
+            """description"""
             print(get_first_arg_name("some_func", verbose=True))
 
         some_func(warg.identity(2))
@@ -264,11 +284,11 @@ if __name__ == "__main__":
             class Bc:
                 @staticmethod
                 def c(d):
-                    """ """
+                    """description"""
                     pass
 
         def some_func(a: Any) -> None:
-            """ """
+            """description"""
             print(get_first_arg_name("some_func", verbose=True))
 
         some_func(Ac.Bc.c(2))
