@@ -210,11 +210,11 @@ NOD.dict_of(spam=spam, foo=x.foo, bar=y['bar'])
 nod = NamedOrderedDictionary()
 
 for arg, value in zip(frame_info.call.args[-len(args) :], args):
-    try:
-        arg_key = node_name(arg)
-        nod[arg_key] = value
-    except TypeError:
-        nod.add_unnamed_arg(value)
+  try:
+      arg_key = node_name(arg)
+      nod[arg_key] = value
+  except TypeError:
+      nod.add_unnamed_arg(value)
 
 nod.update(kwargs)
 
@@ -328,7 +328,7 @@ return nod
         print_str += ")"
         return print_str
 
-    def update(self, *args: Any, **kwargs: Any) -> T:
+    def update(self, *args: Sequence, **kwargs: MutableMapping) -> T:
         """
         Merge two attributes, overriding any repeated keys from
         the `items` parameter.
