@@ -219,7 +219,7 @@ class OrderedSet(MutableSet[T], Sequence[T]):
 
     @overload
     def index(self, key: T) -> int:
-        """ """
+        """description"""
         ...
 
     def index(self, key: Sequence[T]) -> int:
