@@ -32,6 +32,11 @@ from warg import Number, drop_unused_kws
 
 
 def empty_str() -> str:
+    """
+
+    :return:
+    :rtype:
+    """
     return ""
 
 
@@ -43,7 +48,7 @@ def nop() -> None:
 
 
 def identity(a: Any) -> Any:
-    """ """
+    """description"""
     return a
 
 
@@ -82,7 +87,7 @@ def sink(*args, **kwargs) -> None:
     :param args:
     :param kwargs:
     :return:"""
-    return None
+    return
 
 
 def prod(iterable: Iterable[Number]) -> Number:
